oda_api_wrapper
==========================================
*wrapper of API for cdci_data_analysis to overcome 50 scw limitation in INTEGRLA analysis*

What's the license?
-------------------

oda_api is distributed under the terms of The MIT License.

Who's responsible?
-------------------
Carlo Ferrigno

Astronomy Department of the University of Geneva, Chemin d'Ecogia 16, CH-1290 Versoix, Switzerland


Installation
-------------------
1) Anaconda
    * `while read requirement; do conda install --yes $requirement; done < requirements.txt`
    * `python setup.py install`
    
2) PIP
    * `pip install -r requirements.txt`
    * `python setup.py install`

Documentation
-------------------
In the test directory, you can find a notebook with example of usage.

These methods are an elaboration of what can be found at
https://github.com/cdcihub/oda_api_benchmark/tree/master/examples

We refer to oda_api for all documentation.
